summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--src/SMAPI/Patches/CheckEventPreconditionErrorPatch.cs16
1 files changed, 9 insertions, 7 deletions
diff --git a/src/SMAPI/Patches/CheckEventPreconditionErrorPatch.cs b/src/SMAPI/Patches/CheckEventPreconditionErrorPatch.cs
index 63eca5d7..54168969 100644
--- a/src/SMAPI/Patches/CheckEventPreconditionErrorPatch.cs
+++ b/src/SMAPI/Patches/CheckEventPreconditionErrorPatch.cs
@@ -17,8 +17,8 @@ namespace StardewModdingAPI.Patches {
/// <summary>Writes messages to the console and log file on behalf of the game.</summary>
private static IMonitor MonitorForGame;
- /// <summary>Local variable to store the patched method.</summary>
- private static MethodInfo method;
+ /// <summary>Local variable to store the original method.</summary>
+ private static MethodInfo originalMethod;
/// <summary>Local variable to check if the method was already arbitrated.</summary>
private static bool isArbitrated;
@@ -44,9 +44,8 @@ namespace StardewModdingAPI.Patches {
/// <summary>Apply the Harmony patch.</summary>
/// <param name="harmony">The Harmony instance.</param>
public void Apply(HarmonyInstance harmony) {
- method = AccessTools.Method(typeof(GameLocation), "checkEventPrecondition");
- MethodInfo transpiler = AccessTools.Method(this.GetType(), nameof(CheckEventPreconditionErrorPatch.Prefix));
- harmony.Patch(method, new HarmonyMethod(transpiler));
+ originalMethod = AccessTools.Method(typeof(GameLocation), "checkEventPrecondition");
+ harmony.Patch(originalMethod, new HarmonyMethod(AccessTools.Method(this.GetType(), "Prefix")));
}
/*********
@@ -54,19 +53,22 @@ namespace StardewModdingAPI.Patches {
*********/
/// <summary>The method to call instead of the GameLocation.CheckEventPrecondition.</summary>
/// <param name="__instance">The instance being patched.</param>
+ /// <param name="__result">The return value of the original method.</param>
/// <param name="precondition">The precondition to be parsed.</param>
/// <returns>Returns whether to execute the original method.</returns>
/// <remarks>This method must be static for Harmony to work correctly. See the Harmony documentation before renaming arguments.</remarks>
[SuppressMessage("ReSharper", "InconsistentNaming", Justification = "Argument names are defined by Harmony.")]
- private static bool Prefix(GameLocation __instance, string precondition) {
+ private static bool Prefix(GameLocation __instance, ref int __result, string precondition) {
if (isArbitrated) {
isArbitrated = false;
return true;
} else {
isArbitrated = true;
try {
- method.Invoke(__instance, new object[] { precondition });
+ object _ = originalMethod.Invoke(__instance, new object[] { precondition });
+ __result = _ is null ? -1 : (int)_;
} catch (System.Exception ex) {
+ __result = -1;
CheckEventPreconditionErrorPatch.MonitorForGame.Log($"Failed parsing event info. Event precondition: {precondition}\n{ex}", LogLevel.Error);
}